---
name: feat
about: Suggest an idea for this project
title: 'feat:'
labels: Idea
assignees: ''

---

**Is your feature request related to a problem? Please describe.**

**Describe the solution you'd like**

**Describe alternatives you've considered**

**Additional context**
Add any other context or screenshots about the feature request here.
